.. CrunchyFrog Manual documentation master file, created by sphinx-quickstart on Mon Nov 24 12:12:54 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CrunchyFrog Manual
==================

.. toctree::
   :maxdepth: 2

   intro
   datasources
   schema
   queries
   nativeshell
   plugins
   about
   changes

.. Note::
   :kbd:`Keyboard shortcuts` mentioned in this manual always reflect
   the default setting.


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

